@@ -11,7 +11,7 @@ package Term::ANSIEncode;
 #                     Written By Richard Kelsch                       #
 #                  © Copyright 2025 Richard Kelsch                    #
 #                        All Rights Reserved                          #
-#                           Version 1.10                              #
+#                           Version 1.12                              #
 #######################################################################
 # This program is free software: you can redistribute it and/or       #
 # modify it under the terms of the GNU General Public License as      #
@@ -45,7 +45,7 @@ use constant {
 binmode(STDOUT, ":encoding(UTF-8)");
 
 BEGIN {
-    our $VERSION = '1.10';
+    our $VERSION = '1.12';
 }
 
 sub ansi_output {
@@ -88,116 +88,119 @@ sub ansi_output {
 
 sub new {
     my $class = shift;
-    my $self;
 
     my $esc = chr(27) . '[';
 
-    $self->{'ansi_prefix'}    = $esc;
-    $self->{'ansi_sequences'} = {
-        'RETURN'   => chr(13),
-        'LINEFEED' => chr(10),
-        'NEWLINE'  => chr(13) . chr(10),
+	my $self = {
+		'ansi_prefix' => $esc,
+		'mode'        => 'long',
+		'ansi_sequences' => {
+			'RETURN'   => chr(13),
+			'LINEFEED' => chr(10),
+			'NEWLINE'  => chr(13) . chr(10),
 
-        'CLEAR'      => locate(1, 1) . cls,
-        'CLS'        => locate(1, 1) . cls,
-        'CLEAR LINE' => clline,
-        'CLEAR DOWN' => cldown,
-        'CLEAR UP'   => clup,
+			'CLEAR'      => locate(1, 1) . cls,
+			'CLS'        => locate(1, 1) . cls,
+			'CLEAR LINE' => clline,
+			'CLEAR DOWN' => cldown,
+			'CLEAR UP'   => clup,
 
-        # Cursor
-        'UP'          => $esc . 'A',
-        'DOWN'        => $esc . 'B',
-        'RIGHT'       => $esc . 'C',
-        'LEFT'        => $esc . 'D',
-        'SAVE'        => $esc . 's',
-        'RESTORE'     => $esc . 'u',
-        'RESET'       => $esc . '0m',
-        'BOLD'        => $esc . '1m',
-        'FAINT'       => $esc . '2m',
-        'ITALIC'      => $esc . '3m',
-        'UNDERLINE'   => $esc . '4m',
-        'SLOW BLINK'  => $esc . '5m',
-        'RAPID BLINK' => $esc . '6m',
+			# Cursor
+			'UP'          => $esc . 'A',
+			'DOWN'        => $esc . 'B',
+			'RIGHT'       => $esc . 'C',
+			'LEFT'        => $esc . 'D',
+			'SAVE'        => $esc . 's',
+			'RESTORE'     => $esc . 'u',
+			'RESET'       => $esc . '0m',
+			'BOLD'        => $esc . '1m',
+			'FAINT'       => $esc . '2m',
+			'ITALIC'      => $esc . '3m',
+			'UNDERLINE'   => $esc . '4m',
+			'SLOW BLINK'  => $esc . '5m',
+			'RAPID BLINK' => $esc . '6m',
 
-        # Attributes
-        'INVERT'       => $esc . '7m',
-        'REVERSE'      => $esc . '7m',
-        'CROSSED OUT'  => $esc . '9m',
-        'DEFAULT FONT' => $esc . '10m',
-        'FONT1'        => $esc . '11m',
-        'FONT2'        => $esc . '12m',
-        'FONT3'        => $esc . '13m',
-        'FONT4'        => $esc . '14m',
-        'FONT5'        => $esc . '15m',
-        'FONT6'        => $esc . '16m',
-        'FONT7'        => $esc . '17m',
-        'FONT8'        => $esc . '18m',
-        'FONT9'        => $esc . '19m',
+			# Attributes
+			'INVERT'       => $esc . '7m',
+			'REVERSE'      => $esc . '7m',
+			'CROSSED OUT'  => $esc . '9m',
+			'DEFAULT FONT' => $esc . '10m',
+			'FONT1'        => $esc . '11m',
+			'FONT2'        => $esc . '12m',
+			'FONT3'        => $esc . '13m',
+			'FONT4'        => $esc . '14m',
+			'FONT5'        => $esc . '15m',
+			'FONT6'        => $esc . '16m',
+			'FONT7'        => $esc . '17m',
+			'FONT8'        => $esc . '18m',
+			'FONT9'        => $esc . '19m',
 
-        # Color
-        'NORMAL' => $esc . '21m',
+			# Color
+			'NORMAL' => $esc . '21m',
 
-        # Foreground color
-        'BLACK'          => $esc . '30m',
-        'RED'            => $esc . '31m',
-        'PINK'           => $esc . '38;5;198m',
-        'ORANGE'         => $esc . '38;5;202m',
-        'NAVY'           => $esc . '38;5;17m',
-        'GREEN'          => $esc . '32m',
-        'YELLOW'         => $esc . '33m',
-        'BLUE'           => $esc . '34m',
-        'MAGENTA'        => $esc . '35m',
-        'CYAN'           => $esc . '36m',
-        'WHITE'          => $esc . '37m',
-        'DEFAULT'        => $esc . '39m',
-        'BRIGHT BLACK'   => $esc . '90m',
-        'BRIGHT RED'     => $esc . '91m',
-        'BRIGHT GREEN'   => $esc . '92m',
-        'BRIGHT YELLOW'  => $esc . '93m',
-        'BRIGHT BLUE'    => $esc . '94m',
-        'BRIGHT MAGENTA' => $esc . '95m',
-        'BRIGHT CYAN'    => $esc . '96m',
-        'BRIGHT WHITE'   => $esc . '97m',
+			# Foreground color
+			'BLACK'          => $esc . '30m',
+			'RED'            => $esc . '31m',
+			'PINK'           => $esc . '38;5;198m',
+			'ORANGE'         => $esc . '38;5;202m',
+			'NAVY'           => $esc . '38;5;17m',
+			'GREEN'          => $esc . '32m',
+			'YELLOW'         => $esc . '33m',
+			'BLUE'           => $esc . '34m',
+			'MAGENTA'        => $esc . '35m',
+			'CYAN'           => $esc . '36m',
+			'WHITE'          => $esc . '37m',
+			'DEFAULT'        => $esc . '39m',
+			'BRIGHT BLACK'   => $esc . '90m',
+			'BRIGHT RED'     => $esc . '91m',
+			'BRIGHT GREEN'   => $esc . '92m',
+			'BRIGHT YELLOW'  => $esc . '93m',
+			'BRIGHT BLUE'    => $esc . '94m',
+			'BRIGHT MAGENTA' => $esc . '95m',
+			'BRIGHT CYAN'    => $esc . '96m',
+			'BRIGHT WHITE'   => $esc . '97m',
 
-        # Background color
-        'B_BLACK'          => $esc . '40m',
-        'B_RED'            => $esc . '41m',
-        'B_GREEN'          => $esc . '42m',
-        'B_YELLOW'         => $esc . '43m',
-        'B_BLUE'           => $esc . '44m',
-        'B_MAGENTA'        => $esc . '45m',
-        'B_CYAN'           => $esc . '46m',
-        'B_WHITE'          => $esc . '47m',
-        'B_DEFAULT'        => $esc . '49m',
-        'B_PINK'           => $esc . '48;5;198m',
-        'B_ORANGE'         => $esc . '48;5;202m',
-        'B_NAVY'           => $esc . '48;5;17m',
-        'BRIGHT B_BLACK'   => $esc . '100m',
-        'BRIGHT B_RED'     => $esc . '101m',
-        'BRIGHT B_GREEN'   => $esc . '102m',
-        'BRIGHT B_YELLOW'  => $esc . '103m',
-        'BRIGHT B_BLUE'    => $esc . '104m',
-        'BRIGHT B_MAGENTA' => $esc . '105m',
-        'BRIGHT B_CYAN'    => $esc . '106m',
-        'BRIGHT B_WHITE'   => $esc . '107m',
+			# Background color
+			'B_BLACK'          => $esc . '40m',
+			'B_RED'            => $esc . '41m',
+			'B_GREEN'          => $esc . '42m',
+			'B_YELLOW'         => $esc . '43m',
+			'B_BLUE'           => $esc . '44m',
+			'B_MAGENTA'        => $esc . '45m',
+			'B_CYAN'           => $esc . '46m',
+			'B_WHITE'          => $esc . '47m',
+			'B_DEFAULT'        => $esc . '49m',
+			'B_PINK'           => $esc . '48;5;198m',
+			'B_ORANGE'         => $esc . '48;5;202m',
+			'B_NAVY'           => $esc . '48;5;17m',
+			'BRIGHT B_BLACK'   => $esc . '100m',
+			'BRIGHT B_RED'     => $esc . '101m',
+			'BRIGHT B_GREEN'   => $esc . '102m',
+			'BRIGHT B_YELLOW'  => $esc . '103m',
+			'BRIGHT B_BLUE'    => $esc . '104m',
+			'BRIGHT B_MAGENTA' => $esc . '105m',
+			'BRIGHT B_CYAN'    => $esc . '106m',
+			'BRIGHT B_WHITE'   => $esc . '107m',
 
-        'HORIZONTAL RULE ORANGE'         => "\r" . $self->{'ansi_sequences'}->{'B_ORANGE'} . clline . $self->{'ansi_sequences'}->{'RESET'},
-        'HORIZONTAL RULE PINK'           => "\r" . $self->{'ansi_sequences'}->{'B_PINK'} . clline . $self->{'ansi_sequences'}->{'RESET'},
-        'HORIZONTAL RULE RED'            => "\r" . $self->{'ansi_sequences'}->{'B_RED'} . clline . $self->{'ansi_sequences'}->{'RESET'},
-        'HORIZONTAL RULE BRIGHT RED'     => "\r" . $self->{'ansi_sequences'}->{'BRIGHT B_RED'} . clline . $self->{'ansi_sequences'}->{'RESET'},
-        'HORIZONTAL RULE GREEN'          => "\r" . $self->{'ansi_sequences'}->{'B_GREEN'} . clline . $self->{'ansi_sequences'}->{'RESET'},
-        'HORIZONTAL RULE BRIGHT GREEN'   => "\r" . $self->{'ansi_sequences'}->{'BRIGHT B_GREEN'} . clline . $self->{'ansi_sequences'}->{'RESET'},
-        'HORIZONTAL RULE YELLOW'         => "\r" . $self->{'ansi_sequences'}->{'B_YELLOW'} . clline . $self->{'ansi_sequences'}->{'RESET'},
-        'HORIZONTAL RULE BRIGHT YELLOW'  => "\r" . $self->{'ansi_sequences'}->{'BRIGHT B_YELLOW'} . clline . $self->{'ansi_sequences'}->{'RESET'},
-        'HORIZONTAL RULE BLUE'           => "\r" . $self->{'ansi_sequences'}->{'B_BLUE'} . clline . $self->{'ansi_sequences'}->{'RESET'},
-        'HORIZONTAL RULE BRIGHT BLUE'    => "\r" . $self->{'ansi_sequences'}->{'BRIGHT B_BLUE'} . clline . $self->{'ansi_sequences'}->{'RESET'},
-        'HORIZONTAL RULE MAGENTA'        => "\r" . $self->{'ansi_sequences'}->{'B_MAGENTA'} . clline . $self->{'ansi_sequences'}->{'RESET'},
-        'HORIZONTAL RULE BRIGHT MAGENTA' => "\r" . $self->{'ansi_sequences'}->{'BRIGHT B_MAGENTA'} . clline . $self->{'ansi_sequences'}->{'RESET'},
-        'HORIZONTAL RULE CYAN'           => "\r" . $self->{'ansi_sequences'}->{'B_CYAN'} . clline . $self->{'ansi_sequences'}->{'RESET'},
-        'HORIZONTAL RULE BRIGHT CYAN'    => "\r" . $self->{'ansi_sequences'}->{'BRIGHT B_CYAN'} . clline . $self->{'ansi_sequences'}->{'RESET'},
-        'HORIZONTAL RULE WHITE'          => "\r" . $self->{'ansi_sequences'}->{'B_WHITE'} . clline . $self->{'ansi_sequences'}->{'RESET'},
-        'HORIZONTAL RULE BRIGHT WHITE'   => "\r" . $self->{'ansi_sequences'}->{'BRIGHT B_WHITE'} . clline . $self->{'ansi_sequences'}->{'RESET'},
-    };
+			'HORIZONTAL RULE ORANGE'         => "\r" . $esc . '48;5;202m' . clline . $esc . '0m',
+			'HORIZONTAL RULE PINK'           => "\r" . $esc . '48;5;198m' . clline . $esc . '0m',
+			'HORIZONTAL RULE RED'            => "\r" . $esc . '41m'       . clline . $esc . '0m',
+			'HORIZONTAL RULE BRIGHT RED'     => "\r" . $esc . '101m'      . clline . $esc . '0m',
+			'HORIZONTAL RULE GREEN'          => "\r" . $esc . '42m'       . clline . $esc . '0m',
+			'HORIZONTAL RULE BRIGHT GREEN'   => "\r" . $esc . '102m'      . clline . $esc . '0m',
+			'HORIZONTAL RULE YELLOW'         => "\r" . $esc . '43m'       . clline . $esc . '0m',
+			'HORIZONTAL RULE BRIGHT YELLOW'  => "\r" . $esc . '103m'      . clline . $esc . '0m',
+			'HORIZONTAL RULE BLUE'           => "\r" . $esc . '44m'       . clline . $esc . '0m',
+			'HORIZONTAL RULE BRIGHT BLUE'    => "\r" . $esc . '104m'      . clline . $esc . '0m',
+			'HORIZONTAL RULE MAGENTA'        => "\r" . $esc . '45m'       . clline . $esc . '0m',
+			'HORIZONTAL RULE BRIGHT MAGENTA' => "\r" . $esc . '105m'      . clline . $esc . '0m',
+			'HORIZONTAL RULE CYAN'           => "\r" . $esc . '46m'       . clline . $esc . '0m',
+			'HORIZONTAL RULE BRIGHT CYAN'    => "\r" . $esc . '106m'      . clline . $esc . '0m',
+			'HORIZONTAL RULE WHITE'          => "\r" . $esc . '47m'       . clline . $esc . '0m',
+			'HORIZONTAL RULE BRIGHT WHITE'   => "\r" . $esc . '107m'      . clline . $esc . '0m',
+		},
+		@_,
+	};
 
     # Generate generic colors
     foreach my $count (0 .. 255) {
@@ -211,7 +214,14 @@ sub new {
     } ## end foreach my $count (0 .. 255)
 
     # Generate symbols
-    foreach my $u (0x2000 .. 0x2B59) {
+	my $start = 0x2400;
+	my $finish = 0x2605;
+	if ($self->{'mode'} =~ /full|long/i) {
+		$start  = 0x2000;
+		$finish = 0x2B59;
+	}
+
+    foreach my $u ($start .. $finish) {
         my $name = charnames::viacode($u);
         unless ($name =~ /^(ZERO|LINE SEPARATOR|LEFT-TO-RIGHT|PARAGRAPH|POP |RIGHT-TO-LEFT|TRIGRAM|BRAILLE)/) {
             $self->{'characters'}->{$name} = charnames::string_vianame($name);
@@ -242,41 +252,10 @@ Richard Kelsch
 
 =head1 USAGE
 
- ansi_encode.pl file
+ my $obj = Term::ANSIEncode->new();
 
-=head1 OPTIONS
-
-=over 4
-
-=item --B<version> or -B<v>
-
-Shows name, version information and brief licensing information.
-
-=item --B<help> or -B<h>
-
-Simple usage and options documentation
-
-=item --B<tokens> or -B<y>
-
-Shows the most used tokens available.  A token is encapsulated within [% and %] (with at lease one space on each side)
-
-=item --B<symbols> or -B<s> [search]
-
-Similar to "tokens", but instead shows special symbol character tokens.
-
-You may also add a search string to shorten the list.
-
-IT IS HIGHLY SUGGESTED YOU USE A SEARCH STRING.
-
-=back
-
-=over 8
-
-[% RED %]This is written in red[% RESET %]
-
-B<RESET> changes output text to normal.
-
-=back
+Use this version for a full list of symbols:
+ my $obj = Term::ANSIEncode->new('mode' => 'long');
 
 =head1 TOKENS
 
